@@ -1,10 +1,10 @@
 package Sietima::Role::ManualSubscription;
 use Moo::Role;
 use Sietima::Policy;
-use URI;
+use Sietima::HeaderURI;
 use namespace::clean;
 
-our $VERSION = '1.0.0'; # VERSION
+our $VERSION = '1.0.1'; # VERSION
 # ABSTRACT: adds standard list-related headers to messages
 
 with 'Sietima::Role::WithOwner';
@@ -12,16 +12,17 @@ with 'Sietima::Role::WithOwner';
 
 around list_addresses => sub($orig,$self) {
     my $list_name = $self->name // 'the list';
-    my $mail_owner_uri = URI->new($self->owner,'mailto');
-    my $sub_uri = $mail_owner_uri->clone;
-    $sub_uri->query_form(subject => "Please add me to $list_name");
-    my $unsub_uri = $mail_owner_uri->clone;
-    $unsub_uri->query_form(subject => "Please remove me from $list_name");
 
     return +{
         $self->$orig->%*,
-        subscribe => $sub_uri,
-        unsubscribe => $unsub_uri,
+        subscribe => Sietima::HeaderURI->new_from_address(
+            $self->owner,
+            { subject => "Please add me to $list_name" },
+        ),
+        unsubscribe => Sietima::HeaderURI->new_from_address(
+            $self->owner,
+            { subject => "Please remove me from $list_name" },
+        ),
     };
 };
 
@@ -40,7 +41,7 @@ Sietima::Role::ManualSubscription - adds standard list-related headers to messag
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 SYNOPSIS
 
