@@ -1,7 +1,7 @@
 package Sietima::Types;
 use Sietima::Policy;
 use Type::Utils -all;
-use Types::Standard qw(Str HashRef);
+use Types::Standard qw(Str HashRef Defined Str);
 use namespace::clean;
 use Type::Library
     -base,
@@ -9,10 +9,11 @@ use Type::Library
                    Address AddressFromStr
                    TagName
                    EmailMIME Message
+                   HeaderUri HeaderUriFromThings
                    Subscriber SubscriberFromAddress SubscriberFromStr SubscriberFromHashRef
                    Transport MailStore MailStoreFromHashRef);
 
-our $VERSION = '1.0.0'; # VERSION
+our $VERSION = '1.0.1'; # VERSION
 # ABSTRACT: type library for Sietima
 
 
@@ -49,6 +50,12 @@ declare TagName, as Str,
 
 class_type Message, { class => 'Sietima::Message' };
 
+class_type HeaderUri, { class => 'Sietima::HeaderURI' };
+
+declare_coercion HeaderUriFromThings,
+    to_type HeaderUri, from Defined,
+q{ Sietima::HeaderURI->new($_) };
+
 
 class_type Subscriber, { class => 'Sietima::Subscriber' };
 
@@ -78,7 +85,7 @@ Sietima::Types - type library for Sietima
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 DESCRIPTION
 
